.. _cli-reference:

=============
CLI Reference
=============

.. toctree::
   :maxdepth: 1

   cli/cabinet-list
   cli/cabinet-pack
   cli/cabinet-unpack
   cli/serve
   cli/wtml-merge
   cli/wtml-rewrite-urls
